==> haskell-crypton-conduit-0.2.3-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-6UYKO6jV8g2EPNIzfJ0H9G
key:                  crypton-conduit-0.2.3-6UYKO6jV8g2EPNIzfJ0H9G
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  2f097174a41246a36ade91c2adfb8529
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-6UYKO6jV8g2EPNIzfJ0H9G
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8DaA0acFUeIAhiI07RCEeo
    conduit-extra-1.3.6-KIPyqsh9qtn11KuykpUv95
    crypton-1.0.0-33peQlARP7w8sdUNf4ANRc exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-ImDiK8j9yhy8AYzQhyOU1O transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-4JC8kS6zaY8zRxapTpwCf
key:                  crypton-conduit-0.2.3-4JC8kS6zaY8zRxapTpwCf
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  da85cca963bf889ff8397cdcc270432f
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-4JC8kS6zaY8zRxapTpwCf
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5
    conduit-extra-1.3.6-4VZQrDv9KU68F339d2BW5y
    crypton-1.0.0-IIrgJZNDZ7S1y2tDaxcuSw exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
